import {Component} from '@angular/core'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {Company} from '../../../shared/model/company.model'
import {FormField} from '../../../shared/components/entity-add/entity-add.component'
import {CompanyService} from '../../service/company.service'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorHandler, ErrorHandlerComponent, ErrorService} from '../../../shared/service/error.service'
import {AppState} from '../../../shared/app-state'

@Component({
  selector: 'cre-edit',
  templateUrl: './edit.component.html',
  styleUrls: ['./edit.component.sass']
})
export class EditComponent extends ErrorHandlingComponent {
  company: Company | null
  formFields: FormField[] = [
    {
      name: 'name',
      label: 'Nom',
      icon: 'form-textbox',
      type: 'text',
      required: true,
      errorMessages: [
        {conditionFn: errors => errors.required, message: 'Un nom est requis'}
      ]
    }
  ]

  errorHandlers: ErrorHandler[] = [{
    filter: error => error.type === 'notfound-company-id',
    consumer: error => this.urlUtils.navigateTo('/catalog/company/list')
  }, {
    filter: error => error.type === 'exists-company-name',
    messageProducer: error => `Une bannière avec le nom '${error.name}' existe déjà`
  }, {
    filter: error => error.type === 'cannotdelete-company',
    messageProducer: error => 'Cette bannière est utilisée par une ou plusieurs recettes'
  }]

  constructor(
    private companyService: CompanyService,
    private appState: AppState,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit(): void {
    super.ngOnInit()

    const id = parseInt(this.activatedRoute.snapshot.paramMap.get('id'))
    this.subscribeEntityById(
      this.companyService,
      id,
      company => {
        this.appState.title = `${company.name} (Modifications)`
        this.company = company
      }
    )
  }

  submit(values) {
    this.subscribeAndNavigate(
      this.companyService.update(this.company.id, values.name),
      '/catalog/company/list'
    )
  }

  delete() {
    this.subscribeAndNavigate(
      this.companyService.delete(this.company.id),
      '/catalog/company/list'
    )
  }
}
