import {Component} from '@angular/core'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {CompanyService} from '../../service/company.service'
import {Permission} from '../../../shared/model/user'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorService} from '../../../shared/service/error.service'
import {AppState} from '../../../shared/app-state'
import {tap} from 'rxjs/operators'
import {AccountService} from '../../../accounts/services/account.service'

@Component({
  selector: 'cre-list',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.sass']
})
export class ListComponent extends ErrorHandlingComponent {
  companies$ = this.companyService.all.pipe(tap(companies => this.companiesEmpty = companies.length <= 0))
  companiesEmpty = false

  columns = ['name', 'editButton']

  constructor(
    private companyService: CompanyService,
    private accountService: AccountService,
    private appState: AppState,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
    this.appState.title = 'Bannières'
  }

  get hasEditPermission(): boolean {
    return this.accountService.hasPermission(Permission.EDIT_COMPANIES)
  }
}
