import {Component, ViewChild} from '@angular/core'
import {ErrorHandlingComponent} from '../shared/components/subscribing.component'
import {ConfirmBoxComponent} from '../shared/components/confirm-box/confirm-box.component'
import {buildFormControl, Config, ConfigControl} from '../shared/model/config.model'
import {FormBuilder, FormControl, FormGroup} from '@angular/forms'
import {ConfigService} from '../shared/service/config.service'
import {ErrorService} from '../shared/service/error.service'
import {ActivatedRoute, Router} from '@angular/router'

@Component({
  selector: 'cre-config-editor',
  templateUrl: 'config-editor.html'
})
export class CreConfigEditor extends ErrorHandlingComponent {
  @ViewChild('restartingConfirmBox', {static: true}) restartConfirmBox: ConfirmBoxComponent

  keys = {
    INSTANCE_NAME: Config.INSTANCE_NAME,
    INSTANCE_LOGO_SET: Config.INSTANCE_LOGO_SET,
    INSTANCE_ICON_SET: Config.INSTANCE_ICON_SET,
    INSTANCE_URL: Config.INSTANCE_URL,
    DATABASE_URL: Config.DATABASE_URL,
    DATABASE_USER: Config.DATABASE_USER,
    DATABASE_PASSWORD: Config.DATABASE_PASSWORD,
    DATABASE_VERSION: Config.DATABASE_VERSION,
    RECIPE_APPROBATION_EXPIRATION: Config.RECIPE_APPROBATION_EXPIRATION,
    TOUCH_UP_KIT_CACHE_PDF: Config.TOUCH_UP_KIT_CACHE_PDF,
    TOUCH_UP_KIT_EXPIRATION: Config.TOUCH_UP_KIT_EXPIRATION,
    BACKEND_BUILD_VERSION: Config.BACKEND_BUILD_VERSION,
    BACKEND_BUILD_TIME: Config.BACKEND_BUILD_TIME,
    JAVA_VERSION: Config.JAVA_VERSION,
    OPERATING_SYSTEM: Config.OPERATING_SYSTEM
  }

  configs = new Map<string, Config>()
  form: FormGroup | null

  constructor(
    private configService: ConfigService,
    formBuilder: FormBuilder,
    errorService: ErrorService,
    activatedRoute: ActivatedRoute,
    router: Router
  ) {
    super(errorService, activatedRoute, router)

    this.fetchConfigurations(formBuilder)
  }

  ngOnInit() {
    super.ngOnInit()
  }

  getConfigControl(key: string): ConfigControl {
    return {
      config: this.configs.get(key),
      control: this.form.controls[key] as FormControl
    }
  }

  onSubmit() {
    this.subscribe(
      this.configService.setFromForm(this.form),
      () => this.reload()
    )
  }

  restart() {
    this.subscribe(
      this.configService.restart(),
      () => this.restartConfirmBox.show()
    )
  }

  reload() {
    window.location.reload()
  }

  get emergencyMode(): boolean {
    return this.configs.get(Config.EMERGENCY_MODE).content === 'true';
  }

  private fetchConfigurations(formBuilder: FormBuilder) {
    this.subscribe(
      this.configService.all,
      configurations => this.buildForm(formBuilder, configurations)
    )
  }

  private buildForm(formBuilder: FormBuilder, configurations: Config[]) {
    const group = {}
    configurations.forEach(config => {
      group[config.key] = buildFormControl(config)
      this.configs.set(config.key, config)
    })
    this.form = formBuilder.group(group)
  }
}
