import {Component, ViewChild} from '@angular/core'
import {ActivatedRoute, Router} from '@angular/router'
import {Group} from '../../../shared/model/user'
import {GroupService} from '../../services/group.service'
import {Validators} from '@angular/forms'
import {currentPermissionsFieldComponent} from '../../../shared/components/permissions-field/permissions-field.component'
import {AccountService} from '../../../accounts/services/account.service'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {ErrorHandler, ErrorService} from '../../../shared/service/error.service'
import {FormField} from '../../../shared/components/entity-add/entity-add.component'
import {AppState} from '../../../shared/app-state'

@Component({
  selector: 'cre-edit',
  templateUrl: './edit.component.html',
  styleUrls: ['./edit.component.sass']
})
export class EditComponent extends ErrorHandlingComponent {
  @ViewChild('permissionsTemplateRef', {static: true}) permissionsTemplateRef

  formFields: FormField[] = [{
    name: 'name',
    label: 'Nom',
    icon: 'account-multiple',
    type: 'text',
    required: true,
    validator: Validators.minLength(3),
    errorMessages: [
      {conditionFn: errors => errors.required, message: 'Un nom est requis'},
      {conditionFn: errors => errors.minlength, message: 'Le nom d\'un groupe doit comprendre au moins 3 caractères'}
    ]
  }, {
    name: 'permissions',
    label: 'Permissions',
    type: 'permissions'
  }]
  group: Group | null

  errorHandlers: ErrorHandler[] = [{
    filter: error => error.type === 'notfound-group-id',
    consumer: error => this.urlUtils.navigateTo('/admin/group/list')
  }, {
    filter: error => error.type === 'exists-group-name',
    messageProducer: error => `Un groupe avec le nom '${error.name}' existe déjà`
  }]

  constructor(
    private accountService: AccountService,
    private groupService: GroupService,
    private appState: AppState,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit(): void {
    const id = parseInt(this.activatedRoute.snapshot.paramMap.get('id'))
    this.subscribeEntityById(
      this.groupService,
      id,
      group => {
        this.appState.title = `${group.name} (Modifications)`
        this.group = group
      }
    )

    this.formFields[this.formFields.length - 1].template = this.permissionsTemplateRef
  }

  submit(values): void {
    const permissionsField = currentPermissionsFieldComponent
    if (permissionsField.valid()) {
      this.subscribeAndNavigate(
        this.groupService.update(this.group.id, values.name, permissionsField.allEnabledPermissions),
        '/admin/group/list'
      )
    }
  }

  delete() {
    this.subscribeAndNavigate(
      this.groupService.delete(this.group.id),
      '/admin/group/list'
    )
  }
}
