import {Component} from '@angular/core'
import {MaterialTypeService} from '../../service/material-type.service'
import {ErrorHandlingComponent} from '../../../shared/components/subscribing.component'
import {Permission} from '../../../shared/model/user'
import {ActivatedRoute, Router} from '@angular/router'
import {ErrorService} from '../../../shared/service/error.service'
import {AppState} from '../../../shared/app-state'
import {tap} from 'rxjs/operators'
import {AccountService} from '../../../accounts/services/account.service'

@Component({
  selector: 'cre-list',
  templateUrl: './list.component.html',
  styleUrls: ['./list.component.sass']
})
export class ListComponent extends ErrorHandlingComponent {
  materialTypes$ = this.materialTypeService.all.pipe(
    tap(materialTypes => this.materialTypesEmpty = materialTypes.length <= 0)
  )
  materialTypesEmpty = false

  columns = ['name', 'prefix', 'usePercentages', 'editButton']

  constructor(
    private materialTypeService: MaterialTypeService,
    private accountService: AccountService,
    private appState: AppState,
    errorService: ErrorService,
    router: Router,
    activatedRoute: ActivatedRoute
  ) {
    super(errorService, activatedRoute, router)
    this.appState.title = 'Types de produit'
  }

  get hasEditPermission(): boolean {
    return this.accountService.hasPermission(Permission.EDIT_COMPANIES)
  }
}
