import {Injectable} from '@angular/core'
import {ApiService} from '../../shared/service/api.service'
import {Observable} from 'rxjs'

@Injectable({
  providedIn: 'root'
})
export class InventoryService {
  constructor(
    private api: ApiService
  ) {
  }

  add(material: number, quantity: number): Observable<MaterialQuantity[]> {
    return this.api.put<MaterialQuantity[]>('/inventory/add', [{material, quantity}])
  }

  deductMixFromQuantities(mixId: number, originalQuantity: number, currentQuantity: number): Observable<MaterialQuantity[]> {
    return this.deductMix(mixId, currentQuantity / originalQuantity)
  }

  deductMix(mixId: number, ratio: number): Observable<MaterialQuantity[]> {
    const body = {id: mixId, ratio}
    return this.api.put<MaterialQuantity[]>('/inventory/deduct/mix', body)
  }

  deduct(materialQuantities: [{material: number, quantity: number}]): Observable<MaterialQuantity[]> {
    return this.api.put<MaterialQuantity[]>('/inventory/deduct', materialQuantities)
  }
}

export class MaterialQuantity {
  constructor(
    public material: number,
    public quantity: number
  ) {
  }
}
