import {Component, ContentChild, Directive, Input, OnInit, ViewEncapsulation} from '@angular/core'
import {FormBuilder, FormGroup} from '@angular/forms'

export interface ICreForm {
  formGroup: FormGroup
  valid: boolean
  invalid: boolean
}

@Directive({
  selector: 'cre-form-title'
})
export class CreFormTitle {
}

@Directive({
  selector: 'cre-form-content'
})
export class CreFormContent {
}

@Directive({
  selector: 'cre-form-actions'
})
export class CreFormActions {
}

@Component({
  selector: 'cre-form',
  templateUrl: './form.html',
  styleUrls: ['forms.sass'],
  encapsulation: ViewEncapsulation.None
})
export class CreForm implements ICreForm, OnInit {
  @ContentChild(CreFormActions) formActions: CreFormActions
  @Input() formControls: { [key: string]: any }

  formGroup: FormGroup

  constructor(
    private formBuilder: FormBuilder
  ) {
  }

  ngOnInit(): void {
    this.formGroup = this.formBuilder.group(this.formControls)
  }

  get hasActions(): boolean {
    return !!this.formActions
  }

  get valid(): boolean {
    return this.formGroup && this.formGroup.valid
  }

  get invalid(): boolean {
    return !this.formGroup || this.formGroup.invalid
  }
}
