import {Component, OnDestroy, OnInit} from '@angular/core'
import {AppState} from '../../app-state'
import {User} from '../../model/user'
import {Subject} from 'rxjs'
import {takeUntil} from 'rxjs/operators'
import {UrlUtils} from '../../utils/url.utils'
import {ActivatedRoute, Router} from '@angular/router'

@Component({
  selector: 'cre-user-menu',
  templateUrl: './user-menu.component.html',
  styleUrls: ['./user-menu.component.sass']
})
export class UserMenuComponent implements OnInit, OnDestroy {
  authenticated = false
  user: User = null
  userInGroup = false
  menuEnabled = false

  private destroy$ = new Subject<boolean>()
  private urlUtils: UrlUtils

  constructor(
    private appState: AppState,
    private router: Router,
    private activatedRoute: ActivatedRoute
  ) {
    this.urlUtils = new UrlUtils(activatedRoute, router)
  }

  ngOnInit(): void {
    this.authenticationState(this.appState.isAuthenticated, this.appState.authenticatedUser)
    this.appState.authenticatedUser$
      .pipe(takeUntil(this.destroy$))
      .subscribe({
        next: authentication => this.authenticationState(authentication.authenticated, authentication.authenticatedUser)
      })
  }

  ngOnDestroy(): void {
    this.destroy$.next(true)
    this.destroy$.complete()
  }

  openLogin() {
    this.urlUtils.navigateTo('/account/login')
    this.menuEnabled = false
  }

  openLogout() {
    this.urlUtils.navigateTo('/account/logout')
    this.menuEnabled = false
  }

  private authenticationState(authenticated: boolean, user: User) {
    this.authenticated = authenticated
    this.user = user
    if (this.user != null) {
      this.userInGroup = this.user.group != null
    }
  }
}
