import {MaterialType} from './materialtype.model'
import {openPdf} from '../utils/utils'

export class Material {
  constructor(
    public id: number,
    public name: string,
    public inventoryQuantity: number,
    public materialType: MaterialType,
    public simdutUrl: string
  ) {
  }
}

export function openSimdut(material: Material) {
  openPdf(material.simdutUrl)
}

export const materialComparator = (a: Material, b: Material): number => {
  const aPrefixName = a.materialType.prefix.toLowerCase()
  const bPrefixName = b.materialType.prefix.toLowerCase()

  if (aPrefixName < bPrefixName) {
    return -1
  } else if (aPrefixName > bPrefixName) {
    return 1
  } else {
    const aName = a.name.toLowerCase()
    const bName = b.name.toLowerCase()

    if (aName < bName) {
      return -1
    } else if (aName > bName) {
      return 1
    } else {
      return 0
    }
  }
}

// Uses private use UTF-8 char to separate the two fields, change if a better method is found
export const materialFilterFieldSeparator = '􀃿'

export function materialMatchesFilter(material: Material, filter: string): boolean {
  const [materialTypeFilter, materialNameFilter, hideLowQuantity, lowQuantityThreshold] = filter.split(materialFilterFieldSeparator)
  const materialTypeId = parseInt(materialTypeFilter)
  const matchesMaterialType = materialTypeId === 1 || materialTypeId == material.materialType.id
  const matchesMaterialName = !materialNameFilter || material.name.toLowerCase().includes(materialNameFilter.toLowerCase())
  const matchesLowQuantity = material.inventoryQuantity < parseInt(lowQuantityThreshold)

  return matchesMaterialType && matchesMaterialName && (hideLowQuantity === 'false' || matchesLowQuantity)
}
