/** Returns [value] if it is not null or [or]. */
import {DateTimeFormatter, LocalDate, LocalDateTime} from '@js-joda/core'
import {TouchUpKit} from '../model/touch-up-kit.model'
import {environment} from '../../../../environments/environment'

export function valueOr<T>(value: T, or: T): T {
  return value ? value : or
}

const MEDIA_TYPE_PDF = 'application/pdf'
const MEDIA_TYPE_JPG = 'image/jpeg'

export function openPdf(url: string) {
  openUrl(url, MEDIA_TYPE_PDF)
}

export function openJpg(url: string) {
  openUrl(url, MEDIA_TYPE_JPG)
}

export function openTouchUpKit(touchUpKit: TouchUpKit) {
  openRawUrl(`${environment.apiUrl}/touchupkit/pdf?project=${touchUpKit.project}`)
}

export function openUrl(url: string, mediaType: string) {
  openRawUrl(`${url}&mediaType=${encodeURIComponent(mediaType)}`)
}

export function openRawUrl(url: string) {
  window.open(url, '_blank')
}

const dateFormatter = DateTimeFormatter
  .ofPattern('dd-MM-yyyy')
const dateTimeFormatter = DateTimeFormatter
  .ofPattern('dd-MM-yyyy HH:mm:ss')

export function formatDate(date: string): string {
  return LocalDate.parse(date).format(dateFormatter)
}

export function formatDateTime(dateTime: string): string {
  return LocalDateTime.parse(dateTime).format(dateTimeFormatter)
}

export function reduceDashes(arr: string[]): string {
  return arr.reduce((acc, cur) => {
    return `${acc} - ${cur}`
  })
}

export function readFile(file: File, consumer: (any) => void) {
  const reader = new FileReader()
  reader.onload = (e: any) => {
    consumer(e.target.result)
  }
  reader.readAsDataURL(file)
}

export function getFileUrl(path: string) {
  return `${environment.apiUrl}/file?path=${encodeURIComponent(path)}`
}

export function getConfiguredImageUrl(path: string) {
  return `${environment.apiUrl}/config/${path}`
}

export function round(n: number, digits: number): number {
  const power = Math.pow(10, digits)
  return Math.round(n * power) / power
}
