import {Component, EventEmitter, Input, Output, ViewChild} from '@angular/core'
import {chipListRequired, CreInputEntry, CreChipComboBoxComponent} from '../../shared/components/inputs/inputs'
import {CreForm} from '../../shared/components/forms/forms'
import {TouchUpKitProductEditor} from './product-editor'
import {FormControl, Validators} from '@angular/forms'
import {RecipeService} from '../../recipes/services/recipe.service'
import {CompanyService} from '../../company/service/company.service'
import {ErrorService} from '../../shared/service/error.service'
import {ActivatedRoute, Router} from '@angular/router'
import {TouchUpKit, TouchUpKitProduct} from '../../shared/model/touch-up-kit.model'
import {SubscribingComponent} from '../../shared/components/subscribing.component'
import {map} from 'rxjs/operators'

@Component({
  selector: 'touchupkit-form',
  templateUrl: 'form.html'
})
export class TouchUpKitForm extends SubscribingComponent {
  @ViewChild('finishInput') finishInput: CreChipComboBoxComponent
  @ViewChild('materialInput') materialInput: CreChipComboBoxComponent
  @ViewChild(CreForm) form: CreForm
  @ViewChild(TouchUpKitProductEditor) contentEditor: TouchUpKitProductEditor

  @Input() touchUpKit: TouchUpKit | null

  controls: any
  finish$ = this.recipeService.all.pipe(
    map(recipes => recipes.map(recipe => new CreInputEntry(recipe.id, recipe.name, `${recipe.name} - ${recipe.company.name}`)))
  )
  companies$ = this.companyService.all.pipe(
    map(companies => companies.map(company => company.name))
  )

  @Output() submitForm = new EventEmitter<TouchUpKit>()

  constructor(
    private recipeService: RecipeService,
    private companyService: CompanyService,
    errorService: ErrorService,
    activatedRoute: ActivatedRoute,
    router: Router,
  ) {
    super(errorService, activatedRoute, router)
  }

  ngOnInit() {
    super.ngOnInit()

    this.controls = {
      project: new FormControl(this.touchUpKit?.project, Validators.required),
      buggy: new FormControl(this.touchUpKit?.buggy, Validators.required),
      company: new FormControl(this.touchUpKit?.company, Validators.required),
      quantity: new FormControl(this.touchUpKit?.quantity, Validators.compose([Validators.required, Validators.min(1)])),
      shippingDate: new FormControl(this.touchUpKit?.shippingDate, Validators.required),
      finish: new FormControl(this.touchUpKit?.finish, chipListRequired()),
      material: new FormControl(this.touchUpKit?.material, chipListRequired())
    }
  }

  submit() {
    this.submitForm.emit({
      id: this.touchUpKit ? this.touchUpKit.id : null,
      project: this.controls.project.value,
      buggy: this.controls.buggy.value,
      company: this.controls.company.value,
      quantity: this.controls.quantity.value,
      shippingDate: this.controls.shippingDate.value,
      completed: false,
      completionDate: null,
      finish: this.selectedFinish,
      material: this.selectedMaterial,
      content: this.touchUpKitContent
    })
  }

  get selectedFinish(): string[] {
    return this.finishInput.selectedValues
  }

  get selectedMaterial(): string[] {
    return this.materialInput.selectedValues
  }

  get touchUpKitContent(): TouchUpKitProduct[] {
    return this.contentEditor.products
  }

  get formValid(): boolean {
    return this.form && !this.form.invalid &&
      !this.finishInput.empty &&
      !this.materialInput.empty &&
      !this.contentEditor.empty
  }
}
